--[[
Author: Starinnia
CPR is a combo points display addon based on Funkydude's BasicComboPoints
Combo.lua - A module for tracking combo points
$Date: 2010-07-26 20:39:47 +0000 (Mon, 26 Jul 2010) $
$Revision: 110 $
Project Version: r111
contact: codemaster2010 AT gmail DOT com

Copyright (c) 2007-2010 Michael J. Murray aka Lyte of Lothar(US)
All rights reserved unless otherwise explicitly stated.
]]

local cpr = LibStub("AceAddon-3.0"):GetAddon("ComboPointsRedux")
local modName = "Combo Points"
local ComboModule = cpr:NewModule(modName, "AceConsole-3.0", "AceEvent-3.0")
local LSM = LibStub("LibSharedMedia-3.0")
ComboModule.abbrev = "CP"
ComboModule.MAX_POINTS = 5

function ComboModule:OnInitialize()
	self.graphics = cpr:MakeGraphicsFrame(modName, self.MAX_POINTS)
	self.text = cpr:MakeTextFrame(modName)
end

function ComboModule:OnEnable()
	if not cpr.db.profile.modules[modName].disableGraphics then
		self.graphics:Show()
	end
	if not cpr.db.profile.modules[modName].disableText then
		self.text:Show()
	end
	
	self:RegisterEvent("UNIT_COMBO_POINTS")
	self:RegisterEvent("PLAYER_TARGET_CHANGED", "UNIT_COMBO_POINTS")
end

function ComboModule:OnDisable()
	self.graphics:Hide()
	self.text:Hide()
	self:UnregisterEvent("UNIT_COMBO_POINTS")
	self:UnregisterEvent("PLAYER_TARGET_CHANGED")
end

function ComboModule:UNIT_COMBO_POINTS()
	local points = GetComboPoints(UnitHasVehicleUI("player") and "vehicle" or "player", "target")
	if UnitIsDead("target") then points = 0 end
	local r, g, b = cpr:GetColorByPoints(modName, points)
	
	if points == 0 then
		for i = 1, 5 do
			self.graphics.points[i]:Hide()
		end
		points = ""
	else
		for i = points, 1, -1 do
			self.graphics.points[i].icon:SetVertexColor(r, g, b)
			self.graphics.points[i]:Show()
		end
	end
	self.text:SetNumPoints(points)
end

--Set handler for the module options
function ComboModule:Set(info, ...)
	if info.type == "color" then
		if info.arg == "textColor" then
			local color = cpr.db.profile.modules[modName][info.arg]
			color[1], color[2], color[3] = ...
		else
			local color = cpr.db.profile.modules[modName].colors[info.arg]
			color[1], color[2], color[3] = ...
		end
	else
		cpr.db.profile.modules[modName][info.arg] = ...
	end
	cpr:UpdateSettings(modName)
end

--Get handler for the module options
function ComboModule:Get(info, ...)
	if info.type == "color" then
		return unpack(cpr.db.profile.modules[modName].colors[info.arg])
	else
		return cpr.db.profile.modules[modName][info.arg]
	end
end
